-----------------------------------------------------------------------------------------------------------------
--! @file main.vhd
--! @brief Global entity, defines pinout and inteconnections of first level entities.
-----------------------------------------------------------------------------------------------------------------

--! Use standard library.
library ieee;
	--! Use std_[U]logic[_vector].
	use ieee.std_logic_1164.all;

--! Use core entities.
library core_lib;

--! Use security provisions.
library security_lib;

--! @brief Superentity
--! @details Defines relations and connectivity between first level entities.
entity main is
	port (
		INPUT_CLOCK : in std_logic;	--! Oscillator generated clock input
		EXTERNAL_CLOCK : out std_logic; --! Generated clock output
		RESET : out std_logic --! Generated clock output
	);

end entity main;

--! @brief Wired descrition
--! @details The FPGA is described as a series of interconnected modules
architecture Wiring of main is
	signal clock : std_logic := '0'; --! Internal global clock
	signal clock_available : std_logic := '0'; --! Clock PLL stable
	signal internal_reset : std_logic := '0'; --! Internal reset signal
begin
	 --! Clock management unit
	clock_man : entity core_lib.clock_management
		port map (
			base_clock => INPUT_CLOCK,
			derived_clock => clock,
			clock_available => clock_available
		);

        EXTERNAL_CLOCK <= clock;

	--! Reset management unit
	reset_man : entity security_lib.reset_manager
		port map (
			clock => clock,
			clock_available => clock_available,
			internal_reset => internal_reset
		);

	RESET <= internal_reset;

end architecture Wiring;

